"""Block-level components: larger reusable UI patterns.

Aligned with Smartbank Figma design system.
"""

from smarty_ui.blocks.card import bank_card, simple_card
from smarty_ui.blocks.home_card import home_card, home_card_carousel
from smarty_ui.blocks.list_item import list_item, list_item_group, action_item
from smarty_ui.blocks.service_list import service_list, service_list_from_data
from smarty_ui.blocks.receiver_cards_list import receiver_cards_list
from smarty_ui.blocks.contacts_list import contacts_list
from smarty_ui.blocks.balance_widget import (
    balance_widget,
    simple_balance_widget,
    full_balance_widget,
    cards_own_list,
)
from smarty_ui.blocks.transaction_status_widget import (
    transaction_status_widget,
    transaction_success_widget,
    transaction_failed_widget,
    transaction_pending_widget,
    transaction_widget_from_data,
)
from smarty_ui.blocks.payment_status_widget import (
    payment_status_widget,
    payment_success_widget,
    payment_failed_widget,
    payment_pending_widget,
    payment_widget_from_data,
)
from smarty_ui.blocks.home_balance_widget import (
    home_balance_widget,
    home_balance_widget_from_data,
    sample_home_balance_widget,
)
from smarty_ui.blocks.send_money_widget import (
    send_money_widget,
    send_money_widget_from_data,
    sample_send_money_widget,
)

__all__ = [
    # Card blocks
    "bank_card",
    "simple_card",
    # Home card blocks
    "home_card",
    "home_card_carousel",
    # List item blocks
    "list_item",
    "list_item_group",
    "action_item",
    # Service list blocks
    "service_list",
    "service_list_from_data",
    # Receiver cards list
    "receiver_cards_list",
    # Contacts list
    "contacts_list",
    # Balance widget
    "balance_widget",
    "simple_balance_widget",
    "full_balance_widget",
    "cards_own_list",
    # Transaction status widgets
    "transaction_status_widget",
    "transaction_success_widget",
    "transaction_failed_widget",
    "transaction_pending_widget",
    "transaction_widget_from_data",
    # Payment status widgets
    "payment_status_widget",
    "payment_success_widget",
    "payment_failed_widget",
    "payment_pending_widget",
    "payment_widget_from_data",
    # Home balance widget
    "home_balance_widget",
    "home_balance_widget_from_data",
    "sample_home_balance_widget",
    # Send money widget
    "send_money_widget",
    "send_money_widget_from_data",
    "sample_send_money_widget",
]
