"""Atom-level primitives: thin themed wrappers around pydivkit elements.

Aligned with Smartbank Figma design system.
"""

# Text primitives - Smartbank typography styles
from smarty_ui.primitives.text import (
    # New Smartbank styles
    title_1,
    title_2,
    controls_1,
    controls_2,
    text_1,
    text_2,
    text_3,
    caption_1,
    caption_2,
    caption_3,
    # Legacy (backward compatibility)
    label,
    heading,
    paragraph,
    caption,
)

# Image primitives
from smarty_ui.primitives.image import icon, avatar, cover_image

# Button primitives - Smartbank button variants
from smarty_ui.primitives.button import (
    primary_button,
    secondary_button,
    outline_button,
    disabled_button,
    icon_button,
    text_button,
)

# Spacer primitives
from smarty_ui.primitives.spacer import h_spacer, v_spacer

# Divider primitives
from smarty_ui.primitives.divider import divider

# Smarty button primitives
from smarty_ui.primitives.smarty_button import smarty_button, smarty_button_filled

__all__ = [
    # Text - Smartbank styles
    "title_1",
    "title_2",
    "controls_1",
    "controls_2",
    "text_1",
    "text_2",
    "text_3",
    "caption_1",
    "caption_2",
    "caption_3",
    # Text - Legacy
    "label",
    "heading",
    "paragraph",
    "caption",
    # Image
    "icon",
    "avatar",
    "cover_image",
    # Button
    "primary_button",
    "secondary_button",
    "outline_button",
    "disabled_button",
    "icon_button",
    "text_button",
    # Spacer
    "h_spacer",
    "v_spacer",
    # Divider
    "divider",
    # Smarty button
    "smarty_button",
    "smarty_button_filled",
]
