"""Design tokens: colors, typography, spacing, and themes.

Aligned with Smartbank Figma design system.
"""

from smarty_ui.tokens.colors import (
    ColorTokens,
    GRADIENT_PURPLE,
    GRADIENT_BLUE,
    GRADIENT_GREY,
)
from smarty_ui.tokens.typography import TypographyTokens, TextStyle
from smarty_ui.tokens.spacing import SpacingTokens
from smarty_ui.tokens.theme import (
    Theme,
    default_theme,
    dark_theme,
    smartbank_theme,
    light_theme,
)

__all__ = [
    # Color tokens
    "ColorTokens",
    "GRADIENT_PURPLE",
    "GRADIENT_BLUE",
    "GRADIENT_GREY",
    # Typography tokens
    "TypographyTokens",
    "TextStyle",
    # Spacing tokens
    "SpacingTokens",
    # Themes
    "Theme",
    "default_theme",
    "dark_theme",
    "smartbank_theme",
    "light_theme",
]
