"""Molecule-level composites: small groups of atoms combined for reuse.

Aligned with Smartbank Figma design system.
"""

from smarty_ui.composites.icon_label import icon_label
from smarty_ui.composites.input_field import input_field
from smarty_ui.composites.badge import badge, outline_badge
from smarty_ui.composites.avatar_row import avatar_row
from smarty_ui.composites.amount_display import (
    amount_display,
    amount_with_label,
    compact_amount,
)
from smarty_ui.composites.service_list_item import service_list_item
from smarty_ui.composites.chat_bubble import (
    chat_bubble,
    assistant_bubble,
    user_bubble,
    error_bubble,
)
from smarty_ui.composites.numbered_avatar import numbered_avatar, letter_avatar
from smarty_ui.composites.card_balance_item import card_balance_item
from smarty_ui.composites.receiver_card_item import receiver_card_item
from smarty_ui.composites.contact_item import contact_item
from smarty_ui.composites.status_bubble import (
    status_bubble,
    transfer_success_bubble,
    transfer_error_bubble,
    transfer_pending_bubble,
    payment_success_bubble,
    payment_error_bubble,
    payment_pending_bubble,
)

__all__ = [
    "icon_label",
    "input_field",
    "badge",
    "outline_badge",
    "avatar_row",
    # Amount display
    "amount_display",
    "amount_with_label",
    "compact_amount",
    # Service list
    "service_list_item",
    # Chat bubbles
    "chat_bubble",
    "assistant_bubble",
    "user_bubble",
    "error_bubble",
    # Avatars
    "numbered_avatar",
    "letter_avatar",
    # Card items
    "card_balance_item",
    "receiver_card_item",
    # Contact items
    "contact_item",
    # Status bubbles
    "status_bubble",
    "transfer_success_bubble",
    "transfer_error_bubble",
    "transfer_pending_bubble",
    "payment_success_bubble",
    "payment_error_bubble",
    "payment_pending_bubble",
]
